==> eam-wshub-proxyclient-11.6-0-sources.jar: net/datastream/schemas/mp_functions/mp1223_001/MP1223_AddPickListPart_001.java <==

package net.datastream.schemas.mp_functions.mp1223_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_entities.picklistpart_001.PickListPart;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.VERB_Type;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/PickListPart_001}PickListPart"/>
 *       &lt;/sequence>
 *       &lt;attribute name="isFromCreatePickTicketPopup" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
 *       &lt;attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Add" />
 *       &lt;attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="PickListPart" />
 *       &lt;attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *       &lt;attribute name="addplannedwopart" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" default="prompt" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "pickListPart"
})
@XmlRootElement(name = "MP1223_AddPickListPart_001")
public class MP1223_AddPickListPart_001 {

    @XmlElement(name = "PickListPart", namespace = "http://schemas.datastream.net/MP_entities/PickListPart_001", required = true)
    protected PickListPart pickListPart;
    @XmlAttribute(name = "isFromCreatePickTicketPopup")
    protected String isFromCreatePickTicketPopup;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;
    @XmlAttribute(name = "addplannedwopart")
    protected String addplannedwopart;

    /**
     * Obtient la valeur de la propriété pickListPart.
     * 
     * @return
     *     possible object is
     *     {@link PickListPart }
     *     
     */
    public PickListPart getPickListPart() {
        return pickListPart;
    }

    /**
     * Définit la valeur de la propriété pickListPart.
     * 
     * @param value
     *     allowed object is
     *     {@link PickListPart }
     *     
     */
    public void setPickListPart(PickListPart value) {
        this.pickListPart = value;
    }

    /**
     * Obtient la valeur de la propriété isFromCreatePickTicketPopup.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getIsFromCreatePickTicketPopup() {
        if (isFromCreatePickTicketPopup == null) {
            return "false";
        } else {
            return isFromCreatePickTicketPopup;
        }
    }

    /**
     * Définit la valeur de la propriété isFromCreatePickTicketPopup.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setIsFromCreatePickTicketPopup(String value) {
        this.isFromCreatePickTicketPopup = value;
    }

    /**
     * Obtient la valeur de la propriété verb.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.ADD;
        } else {
            return verb;
        }
    }

    /**
     * Définit la valeur de la propriété verb.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Obtient la valeur de la propriété noun.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.PICK_LIST_PART;
        } else {
            return noun;
        }
    }

    /**
     * Définit la valeur de la propriété noun.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Obtient la valeur de la propriété version.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Définit la valeur de la propriété version.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

    /**
     * Obtient la valeur de la propriété addplannedwopart.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAddplannedwopart() {
        if (addplannedwopart == null) {
            return "prompt";
        } else {
            return addplannedwopart;
        }
    }

    /**
     * Définit la valeur de la propriété addplannedwopart.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAddplannedwopart(String value) {
        this.addplannedwopart = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_functions/mp1223_001/MP1223_AddPickListPart_001.java <==

package net.datastream.schemas.mp_functions.mp1223_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_entities.picklistpart_001.PickListPart;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.VERB_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/PickListPart_001}PickListPart"/>
 *       &lt;/sequence>
 *       &lt;attribute name="isFromCreatePickTicketPopup" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
 *       &lt;attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Add" />
 *       &lt;attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="PickListPart" />
 *       &lt;attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *       &lt;attribute name="addplannedwopart" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" default="prompt" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "pickListPart"
})
@XmlRootElement(name = "MP1223_AddPickListPart_001")
public class MP1223_AddPickListPart_001 {

    @XmlElement(name = "PickListPart", namespace = "http://schemas.datastream.net/MP_entities/PickListPart_001", required = true)
    protected PickListPart pickListPart;
    @XmlAttribute(name = "isFromCreatePickTicketPopup")
    protected String isFromCreatePickTicketPopup;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;
    @XmlAttribute(name = "addplannedwopart")
    protected String addplannedwopart;

    /**
     * Gets the value of the pickListPart property.
     * 
     * @return
     *     possible object is
     *     {@link PickListPart }
     *     
     */
    public PickListPart getPickListPart() {
        return pickListPart;
    }

    /**
     * Sets the value of the pickListPart property.
     * 
     * @param value
     *     allowed object is
     *     {@link PickListPart }
     *     
     */
    public void setPickListPart(PickListPart value) {
        this.pickListPart = value;
    }

    /**
     * Gets the value of the isFromCreatePickTicketPopup property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getIsFromCreatePickTicketPopup() {
        if (isFromCreatePickTicketPopup == null) {
            return "false";
        } else {
            return isFromCreatePickTicketPopup;
        }
    }

    /**
     * Sets the value of the isFromCreatePickTicketPopup property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setIsFromCreatePickTicketPopup(String value) {
        this.isFromCreatePickTicketPopup = value;
    }

    /**
     * Gets the value of the verb property.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.ADD;
        } else {
            return verb;
        }
    }

    /**
     * Sets the value of the verb property.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Gets the value of the noun property.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.PICK_LIST_PART;
        } else {
            return noun;
        }
    }

    /**
     * Sets the value of the noun property.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Gets the value of the version property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Sets the value of the version property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

    /**
     * Gets the value of the addplannedwopart property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAddplannedwopart() {
        if (addplannedwopart == null) {
            return "prompt";
        } else {
            return addplannedwopart;
        }
    }

    /**
     * Sets the value of the addplannedwopart property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAddplannedwopart(String value) {
        this.addplannedwopart = value;
    }

}
